==> fern-wifi-cracker_2.7.orig.tar.gz: fern-wifi-cracker-2.7/README.md <==
<hr>
  <h5>Create portable static executables from dynamic executables that will run on every distribution of linux without the need of recompiling, <a target="_blank" href="http://www.elfex-linker.com">Click here</a> for more information</h5>
  <hr>
  
<b>DISCLAIMER</b>: Fern-Wifi-Cracker is designed to be used in testing and discovering flaws in ones own network with the aim of fixing the flaws detected, <b>DO NOT</b> use the program on networks for which you dont have permission, i am not responsible for whatever damage you cause by using this software.
<hr/> 

Visit <a href="http://www.fern-pro.com/">http://www.fern-pro.com</a> for newer downloads
<br>

<a href="http://www.fern-pro.com/"><img src="https://raw.githubusercontent.com/savio-code/savio-project-images/master/Fern/shadow_case.png"/></a>
<br>


<i><b>Fern Wifi Cracker</b></i> is a Wireless security auditing and attack software program written using the <a href="http://www.python.org/">Python Programming Language</a> and the <a href="http://www.riverbankcomputing.co.uk/software/pyqt/intro">Python Qt GUI library</a>, the program is able to crack and recover WEP/WPA/WPS keys and also run other network based attacks on wireless or ethernet based networks</p>

###Operating System Supported
The Software runs on any <i>Linux machine</i> with the programs <a href="#prerequisites">prerequisites</a>, But the program has been tested on the following Linux based operating systems:

<p>1. <a href="http://www.ubuntu.com/">Ubuntu KDE/GNOME</a></p>
<p>2. <a href="http://www.backtrack-linux.org/">BackTrack Linux</a></p>
<p>3. <a href="http://www.backbox.org/">BackBox Linux</a></p>

###Prerequisites
The Program requires the following to run properly:<br>
The following dependencies can be installed using the <i>Debian package installer</i> command on Debian based systems using "apt-get install program" or otherwise downloaded
and installed manually

<p>1. <a href="http://www.aircrack-ng.org/">Aircrack-NG</a></p>
<p>2. <a href="http://www.secdev.org/projects/scapy/">Python-Scapy</a></p>
<p>3. <a href="http://www.riverbankcomputing.co.uk/software/pyqt/intro">Python Qt5</a></p>
<p>4. <a href="http://www.python.org/">Python</a></p>
<p>5. <a href="http://subversion.tigris.org/">Subversion</a></p>
<p>6. <a href="http://invisible-island.net/xterm/">Xterm</a></p>
<p>7. <a href="http://code.google.com/p/reaver-wps/">Reaver</a><i> (for WPS Attacks)</i></p>
<p>8. Macchanger</p>

<hr>

###Features
<hr>
<i>Fern Wifi Cracker</i> currently supports the following features:

<p>1. <i>WEP Cracking with Fragmentation,Chop-Chop, Caffe-Latte, Hirte, ARP Request Replay or WPS attack</i></p>
<p>2. <i>WPA/WPA2 Cracking with Dictionary or WPS based attacks</i></p>
<p>3. <i>Automatic saving of key in database on successful crack</i></p>
<p>4. <i>Automatic Access Point Attack System</i></p>
<p>5. <i>Session Hijacking (Passive and Ethernet Modes)</i></p>
<p>6. <i>Access Point MAC Address Geo Location Tracking</i></p>
<p>7. <i>Internal MITM Engine</i></p>
<p>8. <i>Bruteforce Attacks (HTTP,HTTPS,TELNET,FTP)</i></p>
<p>9. <i>Update Support</i></p>

<hr>

###Installation
Installation on Debian Package supported systems:
<br><hr>
<code>root@host:~# dpkg -i Fern-Wifi-Cracker_1.6_all.deb</code>
<hr><br>

The <i>source code</i> for the program can be fetched using the following command on terminal
<br><hr>
<code>root@host:~# svn checkout http://github.com/savio-code/fern-wifi-cracker/trunk/Fern-Wifi-Cracker/</code>
<hr>

<h3 id="updating">Upgrading and Updating</h3>
<hr>
<img src="http://savio-project-images.googlecode.com/files/update_button.png">
The Program automatically checks for updates each time the program is ran, if the program finds an update, it notifies
user with the message <b><font color="green" size="2pt">New Update is Available</font></b>,  in other to update all you simply have to do is click on the update button
When the button is clicked, allow to download update files until it displays the message <b><font color="red" size="2pt">Please Restart Application</font></b>.
<hr>

###Screenshots:
<hr>
<i><b>Main Window</b></i>
<br>

<img src="http://savio-project-images.googlecode.com/files/main_window.PNG">

<br>
<i><b>WPA Cracking with WPS Attack</b></i>
<br>

<img src="http://savio-project-images.googlecode.com/files/wps_image.PNG">

<hr>

###Other Projects:

https://github.com/savio-code/ghost-phisher

https://github.com/savio-code/hexorbase

<hr>
<h4><i>Please support Fern Wifi Cracker development</i></h4>
<h4>Bitcoin: &nbsp;&nbsp;  1AoBfNLfwDrw4ofZXZVm9YfeaFCXtG9k9B</h4>

==> fern-wifi-cracker_2.8.orig.tar.gz: fern-wifi-cracker-2.8/README.md <==
<hr>
  <h5>Create portable static executables from dynamic executables that will run on every distribution of linux without the need of recompiling, <a target="_blank" href="http://www.elfex-linker.com">Click here</a> for more information</h5>
  <hr>
  
<b>DISCLAIMER</b>: Fern-Wifi-Cracker is designed to be used in testing and discovering flaws in one's own network with the aim of fixing the flaws detected, <b>DO NOT</b> use the program on networks for which you don't have permission, I am not responsible for whatever damage you cause by using this software.
<hr/> 

Visit <a href="http://www.fern-pro.com/">http://www.fern-pro.com</a> for newer downloads
<br>

<a href="http://www.fern-pro.com/"><img src="https://raw.githubusercontent.com/savio-code/savio-project-images/master/Fern/shadow_case.png"/></a>
<br>


<i><b>Fern Wifi Cracker</b></i> is a Wireless security auditing and attack software program written using the <a href="http://www.python.org/">Python Programming Language</a> and the <a href="http://www.riverbankcomputing.co.uk/software/pyqt/intro">Python Qt GUI library</a>, the program is able to crack and recover WEP/WPA/WPS keys and also run other network based attacks on wireless or ethernet based networks</p>

###Operating System Supported
The Software runs on any <i>Linux machine</i> with the programs <a href="#prerequisites">prerequisites</a>, But the program has been tested on the following Linux based operating systems:

<p>1. <a href="http://www.ubuntu.com/">Ubuntu KDE/GNOME</a></p>
<p>2. <a href="http://www.backtrack-linux.org/">BackTrack Linux</a></p>
<p>3. <a href="http://www.backbox.org/">BackBox Linux</a></p>

###Prerequisites
The Program requires the following to run properly:<br>
The following dependencies can be installed using the <i>Debian package installer</i> command on Debian based systems using "apt-get install program" or otherwise downloaded
and installed manually

<p>1. <a href="http://www.aircrack-ng.org/">Aircrack-NG</a></p>
<p>2. <a href="http://www.python.org/">Python 2.7.x</a></p>
<p>3. <a href="http://www.secdev.org/projects/scapy/">Python-Scapy</a></p>
<p>4. <a href="http://www.riverbankcomputing.co.uk/software/pyqt/intro">Python Qt5</a></p>
<p>5. <a href="http://subversion.tigris.org/">Subversion</a></p>
<p>6. <a href="http://invisible-island.net/xterm/">Xterm</a></p>
<p>7. <a href="http://code.google.com/p/reaver-wps/">Reaver</a><i> (for WPS Attacks)</i></p>
<p>8. Macchanger</p>

<hr>

###Features
<hr>
<i>Fern Wifi Cracker</i> currently supports the following features:

<p>1. <i>WEP Cracking with Fragmentation,Chop-Chop, Caffe-Latte, Hirte, ARP Request Replay or WPS attack</i></p>
<p>2. <i>WPA/WPA2 Cracking with Dictionary or WPS based attacks</i></p>
<p>3. <i>Automatic saving of key in database on successful crack</i></p>
<p>4. <i>Automatic Access Point Attack System</i></p>
<p>5. <i>Session Hijacking (Passive and Ethernet Modes)</i></p>
<p>6. <i>Access Point MAC Address Geo Location Tracking</i></p>
<p>7. <i>Internal MITM Engine</i></p>
<p>8. <i>Bruteforce Attacks (HTTP,HTTPS,TELNET,FTP)</i></p>
<p>9. <i>Update Support</i></p>

<hr>

###Installation
Installation on Debian Package supported systems:
<br><hr>
<code>root@host:~# dpkg -i Fern-Wifi-Cracker_1.6_all.deb</code>
<hr><br>

The <i>source code</i> for the program can be fetched using the following command on terminal
<br><hr>
<code>root@host:~# svn checkout http://github.com/savio-code/fern-wifi-cracker/trunk/Fern-Wifi-Cracker/</code>
<hr>

<h3 id="updating">Upgrading and Updating</h3>
<hr>
<img src="http://savio-project-images.googlecode.com/files/update_button.png">
The Program automatically checks for updates each time the program is ran, if the program finds an update, it notifies
user with the message <b><font color="green" size="2pt">New Update is Available</font></b>,  in other to update all you simply have to do is click on the update button
When the button is clicked, allow to download update files until it displays the message <b><font color="red" size="2pt">Please Restart Application</font></b>.
<hr>

###Screenshots:
<hr>
<i><b>Main Window</b></i>
<br>

<img src="http://savio-project-images.googlecode.com/files/main_window.PNG">

<br>
<i><b>WPA Cracking with WPS Attack</b></i>
<br>

<img src="http://savio-project-images.googlecode.com/files/wps_image.PNG">

<hr>

###Other Projects:

https://github.com/savio-code/ghost-phisher

https://github.com/savio-code/hexorbase

<hr>
<h4><i>Please support Fern Wifi Cracker development</i></h4>
<h4>Bitcoin: &nbsp;&nbsp;  1AoBfNLfwDrw4ofZXZVm9YfeaFCXtG9k9B</h4>
